@@ -35,8 +35,9 @@ class Domoticz(IPlugin):
 		bodies = ""
 		entity = jsonInput['outcome']['intent']
 		log.msg("entity :  %s" % (entity))		
-		if jsonInput['outcome']['entities']['location']['value'] :
-			location = jsonInput['outcome']['entities']['location']['value']
+		if jsonInput['outcome']['entities']['location']['body'] :
+			location = jsonInput['outcome']['entities']['location']['body']
+
 #		else:
 #			bodies = "pas de lieu"
 #			location= "VIDE"
